==> techne-0.2.1.tar.gz: techne-0.2.1/src/item.h <==
/* Copyright (C) 2009 Papavasileiou Dimitris                             
 *                                                                      
 * This program is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or    
 * (at your option) any later version.                                  
 *                                                                      
 * This program is distributed in the hope that it will be useful,      
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        
 * GNU General Public License for more details.                         
 *                                                                      
 * You should have received a copy of the GNU General Public License    
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef _ITEM_H_
#define _ITEM_H_

#include <lua.h>
#include <objc/Object.h>

@interface Item: Object {
    Item *left, *right, *up, *down;
    char *key;

    char **properties;
    int bloat;
}

-(id) parent;
-(id) children;
-(id) brother;
-(id) sister;
-(id) root;
-(char *) key;
-(int) bloat;
-(char **) properties;
-(void) add: (int) n Properties: (char*[]) list;
-(void) adoptedBy: (Item *) parent;
-(void) adopt: (Item *)child named: (const char *)key;
-(void) renounce: (Item *)child;

@end

#endif

==> techne-0.2.3.tar.gz: techne-0.2.3/src/item.h <==
/* Copyright (C) 2009 Papavasileiou Dimitris                             
 *                                                                      
 * This program is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or    
 * (at your option) any later version.                                  
 *                                                                      
 * This program is distributed in the hope that it will be useful,      
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        
 * GNU General Public License for more details.                         
 *                                                                      
 * You should have received a copy of the GNU General Public License    
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef _ITEM_H_
#define _ITEM_H_

#include <lua.h>
#include "object.h"

@interface Item: Object {
    Item *left, *right, *up, *down;
    char *key;

    char **properties;
    int bloat;
}

-(id) parent;
-(id) children;
-(id) brother;
-(id) sister;
-(id) root;
-(char *) key;
-(int) bloat;
-(char **) properties;
-(void) add: (int) n Properties: (char*[]) list;
-(void) meetSibling: (Item *)sibling;
-(void) missSibling: (Item *)sibling;
-(void) adoptedBy: (Item *) parent;
-(void) adopt: (Item *)child named: (const char *)key;
-(void) renounce: (Item *)child;

@end

#endif
